@@ -28,10 +28,10 @@ PredictedItemTypeDef = TypedDict(
 
 GetPersonalizedRankingResponseTypeDef = TypedDict(
     "GetPersonalizedRankingResponseTypeDef",
-    {"personalizedRanking": List[PredictedItemTypeDef]},
+    {"personalizedRanking": List["PredictedItemTypeDef"]},
     total=False,
 )
 
 GetRecommendationsResponseTypeDef = TypedDict(
-    "GetRecommendationsResponseTypeDef", {"itemList": List[PredictedItemTypeDef]}, total=False
+    "GetRecommendationsResponseTypeDef", {"itemList": List["PredictedItemTypeDef"]}, total=False
 )
